@@ -223,7 +223,9 @@ ConfigIncludeDummy::ConfigIncludeDummy(FolderSelectionModel *pModel, FolderSelec
 }
 
 QStringList ConfigIncludeDummy::includeList() {
-	return mModel->includedPaths().toList();
+	QStringList lList = mModel->includedPaths().toList();
+	lList.sort();
+	return lList;
 }
 
 void ConfigIncludeDummy::setIncludeList(QStringList pIncludeList) {
@@ -246,7 +248,9 @@ ConfigExcludeDummy::ConfigExcludeDummy(FolderSelectionModel *pModel, FolderSelec
 }
 
 QStringList ConfigExcludeDummy::excludeList() {
-	return mModel->excludedPaths().toList();
+	QStringList lList = mModel->excludedPaths().toList();
+	lList.sort();
+	return lList;
 }
 
 void ConfigExcludeDummy::setExcludeList(QStringList pExcludeList) {
@@ -576,7 +580,7 @@ KPageWidgetItem *BackupPlanWidget::createTypePage(const QString &pBupVersion, co
 	KPageWidgetItem *lPage = new KPageWidgetItem(lButtonGroup);
 	lPage->setName(xi18nc("@title", "Backup Type"));
 	lPage->setHeader(xi18nc("@label", "Select what type of backup you want"));
-	lPage->setIcon(QIcon::fromTheme(QStringLiteral("chronometer")));
+	lPage->setIcon(QIcon::fromTheme(QStringLiteral("folder-sync")));
 	return lPage;
 }
 
@@ -585,7 +589,7 @@ KPageWidgetItem *BackupPlanWidget::createSourcePage() {
 	KPageWidgetItem *lPage = new KPageWidgetItem(mSourceSelectionWidget);
 	lPage->setName(xi18nc("@title", "Sources"));
 	lPage->setHeader(xi18nc("@label", "Select which folders to include in backup"));
-	lPage->setIcon(QIcon::fromTheme(QStringLiteral("folder-important")));
+	lPage->setIcon(QIcon::fromTheme(QStringLiteral("cloud-upload")));
 	return lPage;
 }
 
@@ -683,7 +687,7 @@ KPageWidgetItem *BackupPlanWidget::createDestinationPage() {
 	KPageWidgetItem *lPage = new KPageWidgetItem(lButtonGroup);
 	lPage->setName(xi18nc("@title", "Destination"));
 	lPage->setHeader(xi18nc("@label", "Select the backup destination"));
-	lPage->setIcon(QIcon::fromTheme(QStringLiteral("folder-downloads")));
+	lPage->setIcon(QIcon::fromTheme(QStringLiteral("cloud-download")));
 	return lPage;
 }
 
@@ -789,7 +793,7 @@ KPageWidgetItem *BackupPlanWidget::createSchedulePage() {
 	KPageWidgetItem *lPage = new KPageWidgetItem(lTopWidget);
 	lPage->setName(xi18nc("@title", "Schedule"));
 	lPage->setHeader(xi18nc("@label", "Specify the backup schedule"));
-	lPage->setIcon(QIcon::fromTheme(QStringLiteral("view-time-schedule")));
+	lPage->setIcon(QIcon::fromTheme(QStringLiteral("view-calendar")));
 	return lPage;
 }
 
@@ -820,6 +824,7 @@ KPageWidgetItem *BackupPlanWidget::createAdvancedPage(bool pPar2Available) {
 	lShowHiddenLayout->addWidget(lShowHiddenLabel, 0, 1);
 
 	QWidget *lRecoveryWidget = new QWidget;
+	lRecoveryWidget->setVisible(false);
 	QCheckBox *lRecoveryCheckBox = new QCheckBox;
 	lRecoveryCheckBox->setObjectName(QStringLiteral("kcfg_Generate recovery info"));
 
@@ -847,6 +852,7 @@ KPageWidgetItem *BackupPlanWidget::createAdvancedPage(bool pPar2Available) {
 	connect(mVersionedRadio, SIGNAL(toggled(bool)), lRecoveryWidget, SLOT(setVisible(bool)));
 
 	QWidget *lVerificationWidget = new QWidget;
+	lVerificationWidget->setVisible(false);
 	QCheckBox *lVerificationCheckBox = new QCheckBox(xi18nc("@option:check", "Verify integrity of backups"));
 	lVerificationCheckBox->setObjectName(QStringLiteral("kcfg_Check backups"));
 
